==> trade-center-api-0.9.1.3-xt-20171027.065314-1-sources.jar: cn/com/duiba/order/center/api/remoteservice/RemoteConsumerLimitRecordService.java <==
package cn.com.duiba.order.center.api.remoteservice;

import cn.com.duiba.order.center.api.dto.ConsumerExchangeLimitDto;
import cn.com.duiba.order.center.api.dto.ConsumerLimitRecordMultiDto;
import cn.com.duiba.order.center.api.paramquery.ConsumerExchangeLimitParams;
import cn.com.duiba.wolf.dubbo.DubboResult;

import java.util.List;

/**
 * Created by yansen on 17/5/15.
 */
public interface RemoteConsumerLimitRecordService {

    /**
     *
     * @param consumerLimitRecordMultiDto
     * @return
     */
    public DubboResult<ConsumerLimitRecordMultiDto> insert(ConsumerLimitRecordMultiDto consumerLimitRecordMultiDto);

    /**
     *
     * @param sourceId
     * @param sourceType
     * @return
     */
    public DubboResult<Integer> deleteBySource(Long sourceId, String sourceType);

    /**
     *
     * @param consumerExchangeLimitParams
     * @return
     */
    public DubboResult<Integer> countByItemKey(ConsumerExchangeLimitParams consumerExchangeLimitParams);

    /**
     *
     * @param consumerExchangeLimitParams
     * @return
     */
    public DubboResult<Integer> countByItemKeyAndGmtCreate(ConsumerExchangeLimitParams consumerExchangeLimitParams);

    /**
     *
     * @param consumerExchangeLimitParams
     * @return
     */
    public DubboResult<Integer> countByItemSubKey(ConsumerExchangeLimitParams consumerExchangeLimitParams);

    /**
     *
     * @param consumerExchangeLimitParams
     * @return
     */
    public DubboResult<List<ConsumerExchangeLimitDto>> countByInItemKeySubKey(ConsumerExchangeLimitParams consumerExchangeLimitParams);

    /**
     *
     * @param consumerExchangeLimitParams
     * @return
     */
    public DubboResult<List<ConsumerExchangeLimitDto>> countByInItemKeySubKeyAndGmtCreate(ConsumerExchangeLimitParams consumerExchangeLimitParams);

}

==> trade-center-api-2.1.2-xt1-20180727.071116-1-sources.jar: cn/com/duiba/order/center/api/remoteservice/RemoteConsumerLimitRecordService.java <==
package cn.com.duiba.order.center.api.remoteservice;

import cn.com.duiba.boot.netflix.feign.AdvancedFeignClient;
import cn.com.duiba.order.center.api.dto.ConsumerExchangeLimitDto;
import cn.com.duiba.order.center.api.dto.ConsumerLimitRecordMultiDto;
import cn.com.duiba.order.center.api.paramquery.ConsumerExchangeLimitParams;
import cn.com.duiba.wolf.dubbo.DubboResult;

import java.util.List;

/**
 * Created by yansen on 17/5/15.
 */
@AdvancedFeignClient
public interface RemoteConsumerLimitRecordService {

    /**
     *
     * @param consumerLimitRecordMultiDto
     * @return
     */
    public DubboResult<ConsumerLimitRecordMultiDto> insert(ConsumerLimitRecordMultiDto consumerLimitRecordMultiDto);

    /**
     *
     * @param sourceId
     * @param sourceType
     * @return
     */
    public DubboResult<Integer> deleteBySource(Long sourceId, String sourceType);

    /**
     *
     * @param consumerExchangeLimitParams
     * @return
     */
    public DubboResult<Integer> countByItemKey(ConsumerExchangeLimitParams consumerExchangeLimitParams);

    /**
     *
     * @param consumerExchangeLimitParams
     * @return
     */
    public DubboResult<Integer> countByItemKeyAndGmtCreate(ConsumerExchangeLimitParams consumerExchangeLimitParams);

    /**
     *
     * @param consumerExchangeLimitParams
     * @return
     */
    public DubboResult<Integer> countByItemSubKey(ConsumerExchangeLimitParams consumerExchangeLimitParams);

    /**
     *
     * @param consumerExchangeLimitParams
     * @return
     */
    public DubboResult<List<ConsumerExchangeLimitDto>> countByInItemKeySubKey(ConsumerExchangeLimitParams consumerExchangeLimitParams);

    /**
     *
     * @param consumerExchangeLimitParams
     * @return
     */
    public DubboResult<List<ConsumerExchangeLimitDto>> countByInItemKeySubKeyAndGmtCreate(ConsumerExchangeLimitParams consumerExchangeLimitParams);

    /**
     * 通过参数批量查询
     * @param consumerExchangeLimitParams
     * @return
     */
    public DubboResult<List<ConsumerExchangeLimitDto>> findByParams(ConsumerExchangeLimitParams consumerExchangeLimitParams);

}
